/*
 Copyright (C) 2024 3NSoft Inc.

 This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

import { getGlobalEventsSink } from "@/services";
import { updateAppsAndLaunchersInfoInStore } from "./updateAppsAndLaunchersInfoInStore";
import { useProcessStore } from "@/store";
import { installApp, downloadApp } from "./app-operations";

/**
 * This "controller" function downloads and installs given app version.
 * Respective stores are updated, and global events are emitted.
 * @param appId
 * @param version
 */
export async function downloadAndInstallApp(
  appId: string, version: string
): Promise<void> {
  const $emit = getGlobalEventsSink();
  const procsStore = useProcessStore();

  try {

    await downloadApp(appId, version, procsStore, $emit);

    await installApp(appId, version, procsStore, $emit);

  } catch (err) {
    w3n.log('error', `Failed to download and install app ${appId} version ${version}`);
  } finally {
    await updateAppsAndLaunchersInfoInStore();
  }
}
